==> clutternomore-1.1.3%2B1.21.10-fabric-sources.jar: dev/tazer/clutternomore/client/ClientShapeTooltip.java <==
package dev.tazer.clutternomore.client;

import com.mojang.blaze3d.systems.RenderSystem;
import dev.tazer.clutternomore.ClutterNoMore;
import dev.tazer.clutternomore.ClutterNoMoreClient;
import dev.tazer.clutternomore.common.networking.ShapeTooltip;
import java.util.List;
import net.minecraft.class_10799;
import net.minecraft.class_1792;
import net.minecraft.class_2960;
import net.minecraft.class_327;
import net.minecraft.class_332;
import net.minecraft.class_3532;
import net.minecraft.class_5684;

public class ClientShapeTooltip implements class_5684 {
    public final List<class_1792> shapes;
    public int selectedIndex;

    public ClientShapeTooltip(ShapeTooltip shapeTooltip) {
        shapes = shapeTooltip.shapes();
        selectedIndex = shapeTooltip.selectedIndex();
    }

    @Override
    //? if >1.21.2 {
    public int method_32661(class_327 font) {
    //?} else {
    /*public int getHeight() {
    *///?}
        return ClutterNoMoreClient.showTooltip ? 22 : 0;
    }

    @Override
    public int method_32664(class_327 font) {
        return ClutterNoMoreClient.showTooltip ? shapes.size() * 22 : 0;
    }

    @Override
    //? if >1.21.2 {
    public void method_32666(class_327 font, int mouseX, int mouseY, int width, int height, class_332 guiGraphics) {
    //?} else {
    /*public void renderImage(Font font, int mouseX, int mouseY, GuiGraphics guiGraphics) {
    *///?}
        if (ClutterNoMoreClient.showTooltip) {
            class_2960 selected = ClutterNoMore.location("textures/gui/selected_shape_inventory.png");

            int spacing = 22;
            int startX = mouseX + 2;

            for (int index = 0; index < shapes.size(); index++) {
                int x = startX + index * spacing;
                guiGraphics.method_51427(shapes.get(index).method_7854(), x, mouseY);
            }

            //? if <1.21.2
            /*RenderSystem.enableBlend();*/
            guiGraphics.method_25290(
                    //? if >1.21.6
                    class_10799.field_56883,
                    //? =1.21.5
                    /*RenderType::guiTextured,*/
                    selected, class_3532.method_15375(startX + selectedIndex * spacing) - 3, mouseY - 3, 0, 0, 22, 22, 22, 22);
            //? if <1.21.2
            /*RenderSystem.disableBlend();*/
        }
    }
}

==> clutternomore-1.1.6%2B1.21.5-fabric-sources.jar: dev/tazer/clutternomore/client/ClientShapeTooltip.java <==
package dev.tazer.clutternomore.client;

import com.mojang.blaze3d.systems.RenderSystem;
import dev.tazer.clutternomore.ClutterNoMore;
import dev.tazer.clutternomore.ClutterNoMoreClient;
import dev.tazer.clutternomore.common.networking.ShapeTooltip;
import java.util.List;
import net.minecraft.class_1792;
import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_327;
import net.minecraft.class_332;
import net.minecraft.class_3532;
import net.minecraft.class_5684;

public class ClientShapeTooltip implements class_5684 {
    public final List<class_1792> shapes;
    public int selectedIndex;

    public ClientShapeTooltip(ShapeTooltip shapeTooltip) {
        shapes = shapeTooltip.shapes();
        selectedIndex = shapeTooltip.selectedIndex();
    }

    @Override
    //? if >1.21.2 {
    public int method_32661(class_327 font) {
    //?} else {
    /*public int getHeight() {
    *///?}
        return ClutterNoMoreClient.showTooltip ? 22 : 0;
    }

    @Override
    public int method_32664(class_327 font) {
        return ClutterNoMoreClient.showTooltip ? shapes.size() * 22 : 0;
    }

    @Override
    //? if >1.21.2 {
    public void method_32666(class_327 font, int mouseX, int mouseY, int width, int height, class_332 guiGraphics) {
    //?} else {
    /*public void renderImage(Font font, int mouseX, int mouseY, GuiGraphics guiGraphics) {
    *///?}
        if (ClutterNoMoreClient.showTooltip) {
            class_2960 selected = ClutterNoMore.location("textures/gui/selected_shape_inventory.png");

            int spacing = 22;
            int startX = mouseX + 2;

            for (int index = 0; index < shapes.size(); index++) {
                int x = startX + index * spacing;
                guiGraphics.method_51427(shapes.get(index).method_7854(), x, mouseY);
            }

            //? if <1.21.2
            /*RenderSystem.enableBlend();*/
            guiGraphics.method_25290(
                    //? if >1.21.6
                    /*RenderPipelines.GUI_TEXTURED,*/
                    //? =1.21.5
                    class_1921::method_62277,
                    selected, class_3532.method_15375(startX + selectedIndex * spacing) - 3, mouseY - 3, 0, 0, 22, 22, 22, 22);
            //? if <1.21.2
            /*RenderSystem.disableBlend();*/
        }
    }
}
